@@ -16,7 +16,7 @@ use Exporter;
 	     VT_ARRAY VT_BYREF
 	    );
 
-@EXPORT_OK = qw(CP_ACP CP_OEMCP);
+@EXPORT_OK = qw(CP_ACP CP_OEMCP nothing nullstring);
 
 # Automation data types.
 sub VT_EMPTY {0;}
@@ -45,7 +45,7 @@ sub CP_ACP   {0;}     # ANSI codepage
 sub CP_OEMCP {1;}     # OEM codepage
 
 use overload
-    '+' => 'Add', '-' => 'Sub', '*' => 'Mul', '/' => 'Div',
+    # '+' => 'Add', '-' => 'Sub', '*' => 'Mul', '/' => 'Div',
     '""'     => sub {$_[0]->As(VT_BSTR)},
     '0+'     => sub {$_[0]->As(VT_R8)},
     fallback => 1;
@@ -54,6 +54,14 @@ sub Variant {
     return Win32::OLE::Variant->new(@_);
 }
 
+sub nothing {
+    return Win32::OLE::Variant->new(VT_DISPATCH);
+}
+
+sub nullstring {
+    return Win32::OLE::Variant->new(VT_BSTR);
+}
+
 1;
 
 __END__
@@ -81,6 +89,30 @@ the VT_xxx constants.
 
 =over 8
 
+=item nothing()
+
+The nothing() function returns an empty VT_DISPATCH variant.  It can be
+used to clear an object reference stored in a property
+
+	use Win32::OLE::Variant qw(:DEFAULT nothing);
+	# ...
+	$object->{Property} = nothing;
+
+This has the same effect as the Visual Basic statement
+
+	Set object.Property = Nothing
+
+The nothing() function is B<not> exported by default.
+
+=item nullstring()
+
+The nullstring() function returns a VT_BSTR variant with a NULL string
+pointer.  This is B<not> the same as a VT_BSTR variant with an empty
+string "".  The nullstring() value is the same as the vbNullString
+constant in Visual Basic.
+
+The nullstring() function is B<not> exported by default.
+
 =item Variant(TYPE, DATA)
 
 This is just a function alias of the C<Win32::OLE::Variant->new()>
@@ -103,7 +135,7 @@ For VT_EMPTY and VT_NULL variants, the DATA argument may be omitted.
 For all non-VT_ARRAY variants DATA specifies the initial value.
 
 To create a SAFEARRAY variant, you have to specify the VT_ARRAY flag in
-addition to the variant base type of the array elemnts.  In this cases
+addition to the variant base type of the array elements.  In this cases
 DATA must be a list specifying the dimensions of the array.  Each element
 can be either an element count (indices 0 to count-1) or an array
 reference pointing to the lower and upper array bounds of this dimension:
@@ -113,7 +145,7 @@ reference pointing to the lower and upper array bounds of this dimension:
 This creates a 2-dimensional SAFEARRAY of doubles with 4 elements:
 (1,0), (1,1), (2,0) and (2,1).
 
-A special case is the the creation of one-dimensional VT_UI1 arrays with
+A special case is the creation of one-dimensional VT_UI1 arrays with
 a string DATA argument:
 
 	my $String = Variant(VT_ARRAY|VT_UI1, "String");
@@ -168,7 +200,7 @@ C<$Int> is now a VT_I4 Variant object containing the value of element (1,2).
 
 =item Currency([FORMAT[, LCID]])
 
-This method converts the VARIANT value into a formatted curency string.  The
+This method converts the VARIANT value into a formatted currency string.  The
 FORMAT can be either an integer constant or a hash reference.  Valid constants
 are 0 and LOCALE_NOUSEROVERRIDE.  You get the value of LOCALE_NOUSEROVERRIDE
 from the Win32::OLE::NLS module:
@@ -221,7 +253,7 @@ The constants are available from the Win32::OLE::NLS module:
 
 The following elements can be used to construct a date format string.
 Characters must be specified exactly as given below (e.g. "dd" B<not> "DD").
-Spaces can be inserted anywhere between formating codes, other verbatim
+Spaces can be inserted anywhere between formatting codes, other verbatim
 text should be included in single quotes.
 
 	d	day of month
@@ -272,6 +304,14 @@ method without arguments returns the character array as a Perl string.
 
 	print $String->Get, "\n";
 
+=item IsNothing()
+
+Tests if the object is an empty VT_DISPATCH variant.  See also nothing().
+
+=item IsNullString()
+
+Tests if the object is an empty VT_BSTR variant.  See also nullstring().
+
 =item LastError()
 
 The use of the C<Win32::OLE::Variant->LastError()> method is deprecated.
@@ -364,7 +404,7 @@ The constants are available from the Win32::OLE::NLS module:
 
 The following elements can be used to construct a time format string.
 Characters must be specified exactly as given below (e.g. "dd" B<not> "DD").
-Spaces can be inserted anywhere between formating codes, other verbatim
+Spaces can be inserted anywhere between formatting codes, other verbatim
 text should be included in single quotes.
 
 	h	hours; 12-hour clock
@@ -420,7 +460,7 @@ method first.
 
 The Win32::OLE::Variant class used to have its own set of class variables
 like C<$CP>, C<$LCID> and C<$Warn>.  In version 0.1003 and later of the
-Win32::OLE module these variables have been eleminated.  Now the settings
+Win32::OLE module these variables have been eliminated.  Now the settings
 of Win32::OLE are used by the Win32::OLE::Variant module too.  Please read
 the documentation of the C<Win32::OLE-&gt;Option> class method.
 
